import { AjaxRequest, AjaxResponse } from "rxjs/ajax";
import { ServerConfig } from "@nteract/types";
export declare const normalizeBaseURL: (url?: string) => string;
/**
 * Creates an AJAX request to connect to a given server. This function
 * handles setting the authorization tokens on the request.
 *
 * @param serverConfig Details about the server to connect to.
 * @param uri The URL to connect to, not including the base URL
 * @param opts A set of options to pass to the AJAX request. We mimic jquery.ajax support of a cache option here.
 *
 * @returns A fully-configured AJAX request for connecting to the server.
 */
export declare const createAJAXSettings: (serverConfig: ServerConfig, uri?: string, opts?: Partial<AjaxRequest & {
    cache?: boolean | undefined;
}>) => AjaxRequest;
/**
 * RxJS's AjaxResponse sets `response` as any when we can declare the type returned.
 *
 * This interface is meant to be internal, used as:
 *
 * ```
   ajax('/api/contents') as Observable<JupyterAjaxResponse<Contents>>
   ```
 * or as
 * ```
   ajax('/api/contents').map(resp => {
     if(resp.response.type === "notebook")
   })
   ```
 *
 * NOTE: the response can still be invalid and should likely be validated
 */
export interface JupyterAjaxResponse<ResponseType, ErrorType = string> extends AjaxResponse {
    response: ResponseType | ErrorType;
}
