import { Subject } from "rxjs";
import { ServerConfig } from "@nteract/types";
/**
 * Creates an AjaxObservable for listing running kernels.
 *
 * @param serverConfig The server configuration
 *
 * @returns An Observable with the request response
 */
export declare const list: (serverConfig: ServerConfig) => import("rxjs").Observable<import("rxjs/ajax").AjaxResponse>;
/**
 * Creates an AjaxObservable for getting info about a kernel.
 *
 * @param serverConfig The server configuration
 * @param id The id of the kernel to fetch
 *
 * @returns An Observable with the request response
 */
export declare const get: (serverConfig: ServerConfig, id: string) => import("rxjs").Observable<import("rxjs/ajax").AjaxResponse>;
/**
 * Creates an AjaxObservable for starting a kernel.
 *
 * @param serverConfig The server configuration
 * @param name The name of the kernel to start
 * @param path The path to start the kernel in
 *
 * @returns An Observable with the request response
 */
export declare const start: (serverConfig: ServerConfig, name: string, path: string) => import("rxjs").Observable<import("rxjs/ajax").AjaxResponse>;
/**
 * Creates an AjaxObservable for killing a kernel.
 *
 * @param serverConfig The server configuration
 * @param id The id of the kernel to kill
 *
 * @returns An Observable with the request response
 */
export declare const kill: (serverConfig: ServerConfig, id: string) => import("rxjs").Observable<import("rxjs/ajax").AjaxResponse>;
/**
 * Creates an AjaxObservable for interrupting a kernel.
 *
 * @param serverConfig The server configuration
 * @param id The id of the kernel to interrupt
 *
 * @returns An Observable with the request response
 */
export declare const interrupt: (serverConfig: ServerConfig, id: string) => import("rxjs").Observable<import("rxjs/ajax").AjaxResponse>;
/**
 * Creates an AjaxObservable for restarting a kernel.
 *
 * @param serverConfig The server configuration
 * @param id The id of the kernel to restart
 *
 * @returns An Observable with the request response
 */
export declare const restart: (serverConfig: ServerConfig, id: string) => import("rxjs").Observable<import("rxjs/ajax").AjaxResponse>;
/**
 * Creates a Websocket URL that can be used to initialize a
 * connection with a kernel.
 *
 * @param serverConfig The server configuration
 * @param kernelID The ID of the kernel to connect to
 * @param sessionID The ID of the session to connect as
 *
 * @returns A string with the fully formed Websocket URL
 */
export declare const formWebSocketURL: (serverConfig: ServerConfig, kernelID: string, sessionID?: string | undefined) => string;
/**
 * Creates a connection to a kernel with the given kernelID scoped under
 * a particular sessionID.
 *
 * @param serverConfig The server configuration
 * @param kernelID The ID of the kernel to connect to
 * @param sessionID The ID of the session to connect as
 *
 * @returns A websocket Subject that can be subscribed to
 */
export declare const connect: (serverConfig: ServerConfig, kernelID: string, sessionID?: string | undefined) => Subject<any>;
