"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ajax_1 = require("rxjs/ajax");
const base_1 = require("./base");
/**
 * Creates an AjaxObservable for listing available sessions.
 *
 * @param serverConfig The server configuration
 * @param sessionID Universally unique id for session to be requested.
 *
 * @returns An Observable with the request response
 */
exports.list = (serverConfig) => ajax_1.ajax(base_1.createAJAXSettings(serverConfig, "/api/sessions", { cache: false }));
/**
 * Creates an AjaxObservable for getting a particular session's information.
 *
 * @param serverConfig The server configuration
 * @param sessionID Universally unique id for session to be requested
 *
 * @returns An Observable with the request/response
 */
exports.get = (serverConfig, sessionID) => ajax_1.ajax(base_1.createAJAXSettings(serverConfig, `/api/sessions/${sessionID}`, {
    cache: false
}));
/**
 * Creates an AjaxObservable for destroying a particular session.
 *
 * @param serverConfig The server configuration
 * @param sessionID Unique id for session to be requested
 *
 * @returns An Observable with the request/response
 */
exports.destroy = (serverConfig, sessionID) => ajax_1.ajax(base_1.createAJAXSettings(serverConfig, `/api/sessions/${sessionID}`, {
    method: "DELETE"
}));
/**
 * Creates an AjaxObservable for updating a session.
 *
 * @param serverConfig The server configuration
 * @param sessionID Unique identifier for session to be changed
 * @param body Payload containing new kernel_name, new kernel_id,
 * name of the new session, and the new path.
 *
 * @returns An Observable with the request/response
 */
exports.update = (serverConfig, sessionID, body) => ajax_1.ajax(base_1.createAJAXSettings(serverConfig, `/api/sessions/${sessionID}`, {
    method: "PATCH",
    headers: {
        "Content-Type": "application/json"
    },
    body
}));
/**
 * Creates an AjaxObservable for getting a particular session's information.
 *
 * @param serverConfig  The server configuration
 * @param body Payload containing kernel name, kernel_id, session
 * name, and path for creation of a new session.
 *
 * @returns An Observable with the request/response
 */
exports.create = (serverConfig, body) => ajax_1.ajax(base_1.createAJAXSettings(serverConfig, "/api/sessions", {
    method: "POST",
    headers: {
        "Content-Type": "application/json"
    },
    body
}));
