import { Observable } from "rxjs";
import { AjaxResponse } from "rxjs/ajax";
import { ServerConfig } from "@nteract/types";
/**
 * List all available running terminals.
 *
 * @param serverConfig The server configuration
 *
 * @returns An Observable with the request response
 */
export declare const list: (serverConfig: ServerConfig) => Observable<AjaxResponse>;
/**
 * Create a terminal session.
 *
 * @param serverConfig The server configuration
 *
 * @return An Observable with the request response
 */
export declare const create: (serverConfig: ServerConfig) => Observable<AjaxResponse>;
/**
 * Fetch a terminal session.
 *
 * @param serverConfig The server configuration.
 * @param id ID of the terminal to be fetched.
 *
 * @return An Observable with the request response
 */
export declare const get: (serverConfig: ServerConfig, id: string) => Observable<AjaxResponse>;
/**
 * Delete a running terminal session.
 *
 * @param serverConfig The server configuration
 * @param id ID of the terminal to be fetched
 *
 * @return An Observable with the request response
 */
export declare const destroy: (serverConfig: ServerConfig, id: string) => Observable<AjaxResponse>;
/**
 * Given a server configuration and a terminal ID, this function generates
 * a Websocket URL that can be used
 *
 * @param serverConfig The server configuration
 * @param id ID of the terminal to be fetched
 *
 * @returns A websocket URL for connecting to a terminal
 */
export declare const formWebSocketURL: (serverConfig: ServerConfig, id: string) => string;
