"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ajax_1 = require("rxjs/ajax");
const url_join_1 = __importDefault(require("url-join"));
const base_1 = require("./base");
const formURI = (path) => url_join_1.default("/api/terminals/", path);
/**
 * List all available running terminals.
 *
 * @param serverConfig The server configuration
 *
 * @returns An Observable with the request response
 */
exports.list = (serverConfig) => ajax_1.ajax(base_1.createAJAXSettings(serverConfig, "/api/terminals/", {
    method: "GET"
}));
/**
 * Create a terminal session.
 *
 * @param serverConfig The server configuration
 *
 * @return An Observable with the request response
 */
exports.create = (serverConfig) => ajax_1.ajax(base_1.createAJAXSettings(serverConfig, "/api/terminals/", {
    method: "POST"
}));
/**
 * Fetch a terminal session.
 *
 * @param serverConfig The server configuration.
 * @param id ID of the terminal to be fetched.
 *
 * @return An Observable with the request response
 */
exports.get = (serverConfig, id) => ajax_1.ajax(base_1.createAJAXSettings(serverConfig, formURI(id), {
    method: "GET"
}));
/**
 * Delete a running terminal session.
 *
 * @param serverConfig The server configuration
 * @param id ID of the terminal to be fetched
 *
 * @return An Observable with the request response
 */
exports.destroy = (serverConfig, id) => ajax_1.ajax(base_1.createAJAXSettings(serverConfig, formURI(id), {
    method: "DELETE"
}));
/**
 * Given a server configuration and a terminal ID, this function generates
 * a Websocket URL that can be used
 *
 * @param serverConfig The server configuration
 * @param id ID of the terminal to be fetched
 *
 * @returns A websocket URL for connecting to a terminal
 */
exports.formWebSocketURL = (serverConfig, id) => {
    const baseURL = base_1.normalizeBaseURL(serverConfig.endpoint || serverConfig.url);
    const url = `${baseURL}/terminals/websocket/${id}`;
    return url.replace(/^http(s)?/, "ws$1");
};
